---
title: Gramex init
prefix: Init
...

To create an empty project, run `gramex init`.

## Gramex init usage

Run `gramex init` on your terminal.

<link rel="stylesheet" type="text/css" href="../node_modules/asciinema-player/resources/public/css/asciinema-player.css">
<asciinema-player src="gramex-init.rec" cols="100" rows="20" idle-time-limit="0.5"></asciinema-player>

It generates a simple boilerplate:

- `gramex.yaml`: Gramex [configuration](../config/)
- `index.html`: default home page
- `README.md`: project documentation

... and a set of configurations that help development.

- `.editorconfig` [info](http://editorconfig.org/)
- `.eslintrc.js` [info](https://eslint.org/docs/user-guide/configuring)
- `.flake8` [info](http://flake8.pycqa.org/en/latest/user/configuration.html)
- `.gitignore` [info](https://git-scm.com/docs/gitignore)
- `.gitlab-ci.yml` [info](https://docs.gitlab.com/ce/ci/yaml/)
- `.htmllintrc` [info](https://github.com/htmllint/htmllint)
- `.stylelintrc.js` [info](https://stylelint.io/user-guide/configuration/)


## Gramex init tracker

The status of `gramex init` adoption in projects is tracked on [codogram](https://learn.gramener.com/codogram/#projects/) (init column).

<script src="../node_modules/asciinema-player/resources/public/js/asciinema-player.js"></script>
